import * as prompts from "@clack/prompts";
import chalk from "chalk";
import { parseArgs } from "node:util";
import { fromZodError } from "zod-validation-error";
import { createRerunSuggestion } from "../create/createRerunSuggestion.js";
import { create } from "../create/index.js";
import { initialize } from "../initialize/index.js";
import { migrate } from "../migrate/index.js";
import { logLine } from "../shared/cli/lines.js";
import { StatusCodes } from "../shared/codes.js";
import { promptForMode } from "./mode.js";
const operationMessage = (verb) => `Operation ${verb}. Exiting - maybe another time? \u{1F44B}`;
async function bin(args) {
  console.clear();
  prompts.intro(
    [
      chalk.greenBright(`Welcome to`),
      chalk.bgGreenBright.black(`create-typescript-app`),
      chalk.greenBright(`! \u{1F389}`)
    ].join(" ")
  );
  logLine();
  logLine(
    chalk.yellow(
      "\u26A0\uFE0F This template is early stage, opinionated, and not endorsed by the TypeScript team. \u26A0\uFE0F"
    )
  );
  logLine(
    chalk.yellow(
      "\u26A0\uFE0F If any tooling it sets displeases you, you can always remove that portion manually. \u26A0\uFE0F"
    )
  );
  const { values } = parseArgs({
    args,
    options: {
      mode: { type: "string" }
    },
    strict: false
  });
  const mode = await promptForMode(values.mode);
  if (typeof mode !== "string") {
    prompts.outro(chalk.red(mode?.message ?? operationMessage("cancelled")));
    return 1;
  }
  const runners = { create, initialize, migrate };
  const { code, options, zodError } = await runners[mode](args);
  prompts.log.info(
    [
      chalk.italic(`Tip: to run again with the same input values, use:`),
      chalk.blue(createRerunSuggestion(mode, options))
    ].join(" ")
  );
  if (code) {
    logLine();
    if (zodError) {
      const validationError = fromZodError(zodError);
      logLine(chalk.red(validationError));
      logLine();
    }
    prompts.cancel(
      code === StatusCodes.Cancelled ? operationMessage("cancelled") : operationMessage("failed")
    );
  }
  return code;
}
export {
  bin
};
//# sourceMappingURL=index.js.map