import * as prompts from "@clack/prompts";
import chalk from "chalk";
import { filterPromptCancel } from "../shared/prompts.js";
const allowedModes = ["create", "initialize", "migrate"];
function isMode(input) {
  return allowedModes.includes(input);
}
async function promptForMode(input) {
  if (input) {
    if (!isMode(input)) {
      return new Error(
        `Unknown --mode: ${input}. Allowed modes are: ${allowedModes.join(
          ", "
        )}.`
      );
    }
    return input;
  }
  const label = (base, text) => `${chalk.bold(base)} ${text}`;
  const selection = filterPromptCancel(
    await prompts.select({
      message: chalk.blue("How would you like to use the template?"),
      options: [
        {
          label: label("create", "a new repository in a child directory"),
          value: "create"
        },
        {
          label: label(
            "initialize",
            "a freshly repository in the current directory"
          ),
          value: "initialize"
        },
        {
          label: label(
            "migrate",
            "an existing repository in the current directory"
          ),
          value: "migrate"
        }
      ]
    })
  );
  return selection;
}
export {
  promptForMode
};
//# sourceMappingURL=mode.js.map